import { Job } from "../";
export interface PytestProps {
    /**
     * This argument is only required if you have a custom command
     * to call pytest.
     */
    readonly pytestCommand?: string;
    /**
     * The version hint of pipenv to install if `Pipfile.lock` is found.
     * For example '==2022.08.15'. Defaults to latest package version.
     */
    readonly pipenvVersionSpecifier?: string;
    /**
     * The name of the Bootstrap job.
     */
    readonly jobName?: string;
    /**
     * The stage of the Bootstrap job.
     */
    readonly jobStage?: string;
}
export interface IPytest {
    /**
     * This argument is only required if you have a custom command
     * to call pytest.
     */
    pytestCommand: string;
    /**
     * The version hint of pipenv to install if `Pipfile.lock` is found.
     * For example '==2022.08.15'. Defaults to latest package version.
     */
    pipenvVersionSpecifier: string;
}
/**
 * Runs `pytest` and installs project requirements before
 * `PythonScripts.pipInstallRequirements`
 *
 * - Requires a `Pipfile.lock` or `requirements.txt` in your project folder
 *   containing at least `pytest`
 *
 * This subclass of `Job` will configure following defaults for the superclass:
 *
 * - name: pytest
 * - stage: test
 */
export declare class Pytest extends Job implements IPytest {
    pytestCommand: string;
    pipenvVersionSpecifier: string;
    constructor(props: PytestProps);
    render(): any;
}
export interface EvaluateGitTagPep440ConformityProps {
    /**
     * The name of the Bootstrap job.
     */
    readonly jobName?: string;
    /**
     * The stage of the Bootstrap job.
     */
    readonly jobStage?: string;
}
export interface IEvaluateGitTagPep440Conformity {
}
/**
 * Checks if the current pipelines `$CI_COMMIT_TAG` validates to a valid Python
 * package version according to https://www.python.org/dev/peps/pep-0440
 *
 * This job already contains a rule to only run when a `$CI_COMMIT_TAG` is
 * present (`rules.only_tags()`).
 *
 * Runs `pytest` and installs project requirements before
 * `PythonScripts.pipInstallRequirements`
 *
 * - Requires a `requirements.txt` in your project folder containing
 *   at least `pytest`
 *
 * This subclass of `Job` will configure following defaults for the superclass:
 *
 * - name: tag-pep440-conformity
 * - stage: test
 * - image: PredefinedImages.GCIP
 * - rules: on_tagsg
 */
export declare class EvaluateGitTagPep440Conformity extends Job implements IEvaluateGitTagPep440Conformity {
    constructor(props: EvaluateGitTagPep440ConformityProps);
    render(): any;
}
